@@ -14,7 +14,7 @@ use Software::GenoScan::OutputProcessor qw(writeOutput);
 use Software::GenoScan::Regression qw(benchmarkRegModel retrainRegModel);
 require Exporter;
 
-our $VERSION = "v1.0.3";
+our $VERSION = "v1.0.4";
 our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ("all" => [ qw(
 	runGenoScan
@@ -55,17 +55,6 @@ sub checkEnvSanity(){
 	if(!$path){
 		die "GenoScan error: RNAfold not found, terminating\n";
 	}
-	system("echo 'A' | $RNAfold &> log");
-	open(LOG, "log") or die "GenoScan error: Unable to run RNAfold\n";
-	my $log = <LOG>;
-	my $debug = qx(cat log);
-	$debug =~ s/\r//g;
-	$log =~ s/\s|\r//g;
-	close(LOG);
-	system("rm log");
-	if($log ne "A"){
-		$RNAfold = "RNAfold -noPS";
-	}
 	Software::GenoScan::InputProcessor::commandRNAfold($RNAfold);
 	Software::GenoScan::Regression::commandRNAfold($RNAfold);
 }
